@@ -1,21 +1,8 @@
 import ast
 import io
 import sys
-from types import ModuleType
 from typing import no_type_check
 
-if sys.version_info >= (3, 7):
-
-    def is_namespace_module(module: ModuleType) -> bool:
-        return module.__file__ is None
-
-
-else:
-
-    def is_namespace_module(module: ModuleType) -> bool:
-        return getattr(module, "__file__", None) is None
-
-
 if sys.version_info >= (3, 8):
     # Bridge the change from ast.Str to ast.Constant
 
@@ -30,7 +17,6 @@ if sys.version_info >= (3, 8):
     def make_ast_constant_str(value: str) -> ast.Constant:
         return ast.Constant(value=value, kind=None)
 
-
 else:
 
     ast_constant_type = ast.Str
