@@ -1,10 +1,13 @@
+from typing import Dict, List
+
 from django.core.management.commands.makemigrations import Command as BaseCommand
+from django.db.migrations import Migration
 
 from django_linear_migrations.apps import MigrationDetails, first_party_app_configs
 
 
 class Command(BaseCommand):
-    def write_migration_files(self, changes):
+    def write_migration_files(self, changes: Dict[str, List[Migration]]) -> None:
         super().write_migration_files(changes)
         if self.dry_run:
             return
